==> haskell-sqlite-simple-0.4.19.0-63-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sqlite-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sqlite-simple
version:              0.4.19.0
visibility:           public
id:                   sqlite-simple-0.4.19.0-7tqUtYdqBLr6B3ZgdweTEP
key:                  sqlite-simple-0.4.19.0-7tqUtYdqBLr6B3ZgdweTEP
license:              BSD-3-Clause
copyright:
    (c) 2011 MailRank, Inc.,
    (c) 2011-2012 Leon P Smith,
    (c) 2012-2014 Janne Hellsten

maintainer:           Janne Hellsten <jjhellst@gmail.com>
author:               Bryan O'\''Sullivan, Leon P Smith, Janne Hellsten
stability:            stable
homepage:             http://github.com/nurpax/sqlite-simple
synopsis:             Mid-Level SQLite client library
description:
    Mid-level SQLite client library, based on postgresql-simple.

    Main documentation (with examples): <docs/Database-SQLite-Simple.html Database.SQLite.Simple>

    You can view the project page at <http://github.com/nurpax/sqlite-simple>
    for more information.

category:             Database
abi:                  650a3095d59ebc0612fa8b600c6f85b3
exposed:              True
exposed-modules:
    Database.SQLite.Simple Database.SQLite.Simple.FromField
    Database.SQLite.Simple.FromRow Database.SQLite.Simple.Function
    Database.SQLite.Simple.Internal Database.SQLite.Simple.Ok
    Database.SQLite.Simple.QQ Database.SQLite.Simple.Time
    Database.SQLite.Simple.Time.Implementation
    Database.SQLite.Simple.ToField Database.SQLite.Simple.ToRow
    Database.SQLite.Simple.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/sqlite-simple-0.4.19.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/sqlite-simple-0.4.19.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/sqlite-simple-0.4.19.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sqlite-simple
hs-libraries:         HSsqlite-simple-0.4.19.0-7tqUtYdqBLr6B3ZgdweTEP
depends:
    Only-0.1-2ALIOaFTuVl17VyQ33BnR1
    attoparsec-0.14.4-AS2Ju05FAjs55rPAuL3miO base-4.17.2.1
    blaze-builder-0.4.4-9TwQ27zteac6dzdX8WGk7W
    blaze-textual-0.2.3.1-LC7fBweGISBFT76jmJKMGm bytestring-0.11.5.3
    containers-0.6.7 direct-sqlite-2.3.29-2IuIfsoSxQ0DWUWYkUGlxF
    exceptions-0.10.5 template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-sqlite-simple/html/sqlite-simple.haddock

haddock-html:         /usr/share/doc/haskell-sqlite-simple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sqlite-simple-0.4.19.0-64-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sqlite-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sqlite-simple
version:              0.4.19.0
visibility:           public
id:                   sqlite-simple-0.4.19.0-9PAPa6yeggFJjHLqLHRY1d
key:                  sqlite-simple-0.4.19.0-9PAPa6yeggFJjHLqLHRY1d
license:              BSD-3-Clause
copyright:
    (c) 2011 MailRank, Inc.,
    (c) 2011-2012 Leon P Smith,
    (c) 2012-2014 Janne Hellsten

maintainer:           Janne Hellsten <jjhellst@gmail.com>
author:               Bryan O'\''Sullivan, Leon P Smith, Janne Hellsten
stability:            stable
homepage:             http://github.com/nurpax/sqlite-simple
synopsis:             Mid-Level SQLite client library
description:
    Mid-level SQLite client library, based on postgresql-simple.

    Main documentation (with examples): <docs/Database-SQLite-Simple.html Database.SQLite.Simple>

    You can view the project page at <http://github.com/nurpax/sqlite-simple>
    for more information.

category:             Database
abi:                  34f1f76a1a63a93f3a137b076f8b25ca
exposed:              True
exposed-modules:
    Database.SQLite.Simple Database.SQLite.Simple.FromField
    Database.SQLite.Simple.FromRow Database.SQLite.Simple.Function
    Database.SQLite.Simple.Internal Database.SQLite.Simple.Ok
    Database.SQLite.Simple.QQ Database.SQLite.Simple.Time
    Database.SQLite.Simple.Time.Implementation
    Database.SQLite.Simple.ToField Database.SQLite.Simple.ToRow
    Database.SQLite.Simple.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/sqlite-simple-0.4.19.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/sqlite-simple-0.4.19.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/sqlite-simple-0.4.19.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sqlite-simple
hs-libraries:         HSsqlite-simple-0.4.19.0-9PAPa6yeggFJjHLqLHRY1d
depends:
    Only-0.1-2ALIOaFTuVl17VyQ33BnR1
    attoparsec-0.14.4-BOYjI7Xnyxi2UxSSzbjWOG base-4.17.2.1
    blaze-builder-0.4.4-Lx3iAaL3SPqLsOeZbYO5TI
    blaze-textual-0.2.3.1-LLtPt1XgsGH2l3HwprLxiW bytestring-0.11.5.3
    containers-0.6.7 direct-sqlite-2.3.29-IfOPZJwJBbO49wrFSDvmEG
    exceptions-0.10.5 template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-sqlite-simple/html/sqlite-simple.haddock

haddock-html:         /usr/share/doc/haskell-sqlite-simple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
